PyOffers
========
Python client library for `HasOffers API <http://developers.hasoffers.com/>`_

|Build Status| |codecov.io|



.. |Build Status| image:: https://travis-ci.org/Stranger6667/pyoffers.svg?branch=master
   :target: https://travis-ci.org/Stranger6667/pyoffers

.. |codecov.io| image:: https://codecov.io/github/Stranger6667/pyoffers/coverage.svg?branch=master
    :target: https://codecov.io/github/Stranger6667/pyoffers?branch=master